==> duckdb_0.3.2-2.tar.gz: duckdb/src/duckdb/amalgamation-9.cpp <==
#include "src/function/table/system/duckdb_constraints.cpp"

#include "src/function/table/system/duckdb_dependencies.cpp"

#include "src/function/table/system/duckdb_functions.cpp"

#include "src/function/table/system/duckdb_indexes.cpp"

#include "src/function/table/system/duckdb_keywords.cpp"

#include "src/function/table/system/duckdb_schemas.cpp"

#include "src/function/table/system/duckdb_sequences.cpp"

#include "src/function/table/system/duckdb_settings.cpp"

#include "src/function/table/system/duckdb_tables.cpp"

#include "src/function/table/system/duckdb_types.cpp"

#include "src/function/table/system/duckdb_views.cpp"

#include "src/function/table/system/pragma_collations.cpp"

#include "src/function/table/system/pragma_database_list.cpp"

#include "src/function/table/system/pragma_database_size.cpp"

#include "src/function/table/system/pragma_functions.cpp"

#include "src/function/table/system/pragma_storage_info.cpp"

#include "src/function/table/system/pragma_table_info.cpp"

#include "src/function/table/system/test_all_types.cpp"

#include "src/function/table/system_functions.cpp"

#include "src/function/table/table_scan.cpp"

#include "src/function/table/unnest.cpp"

#include "src/function/table/version/pragma_version.cpp"

#include "src/function/table_function.cpp"

#include "src/function/udf_function.cpp"

#include "src/main/appender.cpp"

#include "src/main/capi/appender-c.cpp"

#include "src/main/capi/arrow-c.cpp"

#include "src/main/capi/config-c.cpp"

#include "src/main/capi/datetime-c.cpp"

#include "src/main/capi/duckdb-c.cpp"

#include "src/main/capi/helper-c.cpp"

#include "src/main/capi/hugeint-c.cpp"

#include "src/main/capi/prepared-c.cpp"

#include "src/main/capi/result-c.cpp"

#include "src/main/capi/value-c.cpp"

#include "src/main/client_context.cpp"

#include "src/main/client_context_file_opener.cpp"

#include "src/main/config.cpp"

#include "src/main/connection.cpp"

#include "src/main/database.cpp"

#include "src/main/extension.cpp"

#include "src/main/extension/extension_helper.cpp"

#include "src/main/extension/extension_install.cpp"

#include "src/main/extension/extension_load.cpp"

#include "src/main/materialized_query_result.cpp"

#include "src/main/pending_query_result.cpp"

==> duckdb_0.3.4.tar.gz: duckdb/src/duckdb/amalgamation-9.cpp <==
#include "src/function/table/system/duckdb_constraints.cpp"

#include "src/function/table/system/duckdb_dependencies.cpp"

#include "src/function/table/system/duckdb_functions.cpp"

#include "src/function/table/system/duckdb_indexes.cpp"

#include "src/function/table/system/duckdb_keywords.cpp"

#include "src/function/table/system/duckdb_schemas.cpp"

#include "src/function/table/system/duckdb_sequences.cpp"

#include "src/function/table/system/duckdb_settings.cpp"

#include "src/function/table/system/duckdb_tables.cpp"

#include "src/function/table/system/duckdb_types.cpp"

#include "src/function/table/system/duckdb_views.cpp"

#include "src/function/table/system/pragma_collations.cpp"

#include "src/function/table/system/pragma_database_list.cpp"

#include "src/function/table/system/pragma_database_size.cpp"

#include "src/function/table/system/pragma_functions.cpp"

#include "src/function/table/system/pragma_storage_info.cpp"

#include "src/function/table/system/pragma_table_info.cpp"

#include "src/function/table/system/test_all_types.cpp"

#include "src/function/table/system_functions.cpp"

#include "src/function/table/table_scan.cpp"

#include "src/function/table/unnest.cpp"

#include "src/function/table/version/pragma_version.cpp"

#include "src/function/table_function.cpp"

#include "src/function/table_macro_function.cpp"

#include "src/function/udf_function.cpp"

#include "src/main/appender.cpp"

#include "src/main/capi/appender-c.cpp"

#include "src/main/capi/arrow-c.cpp"

#include "src/main/capi/config-c.cpp"

#include "src/main/capi/data_chunk-c.cpp"

#include "src/main/capi/datetime-c.cpp"

#include "src/main/capi/duckdb-c.cpp"

#include "src/main/capi/duckdb_value-c.cpp"

#include "src/main/capi/helper-c.cpp"

#include "src/main/capi/hugeint-c.cpp"

#include "src/main/capi/logical_types-c.cpp"

#include "src/main/capi/prepared-c.cpp"

#include "src/main/capi/replacement_scan-c.cpp"

#include "src/main/capi/result-c.cpp"

#include "src/main/capi/table_function-c.cpp"

#include "src/main/capi/value-c.cpp"

#include "src/main/client_context.cpp"

#include "src/main/client_context_file_opener.cpp"

#include "src/main/config.cpp"

#include "src/main/connection.cpp"

#include "src/main/database.cpp"

#include "src/main/extension.cpp"
